==> hlog-0.20-rc1.tar.gz: hlog-0.20-rc1/hlog/common/recent.h <==
/*
 * Copyright (c) 2021 Josef 'Jeff' Sipek <jeffpc@josefsipek.net>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

#ifndef __RECENT_H
#define __RECENT_H

#include <ncurses.h>

extern int recent_init(int height, int width, int row, int col);
extern void recent_destroy(void);
extern void recent_invalidate(void);
extern void recent_refresh(void);

/*
 * Legacy recent code, to be removed in the future
 */
extern void refresh_recent_win(WINDOW *win, int height, int width,
			       bool count);

#endif

==> hlog-0.22.tar.gz: hlog-0.22/hlog/common/recent.h <==
/*
 * Copyright (c) 2021-2022 Josef 'Jeff' Sipek <jeffpc@josefsipek.net>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

#ifndef __RECENT_H
#define __RECENT_H

#include <ncurses.h>

struct recent_line;

struct recent {
	WINDOW *win;
	size_t nrows;
	size_t ncols;
	struct recent_line **lines;
	bool all;
	bool reeval;
};

extern int recent_init(struct recent *recent, int height, int width, int row,
		       int col, bool all);
extern void recent_destroy(struct recent *recent);
extern void recent_invalidate(struct recent *recent);
extern void recent_refresh(struct recent *recent, struct str *call);

/*
 * Legacy recent code, to be removed in the future
 */
extern void refresh_recent_win(WINDOW *win, int height, int width,
			       bool count);

#endif
